@@ -7,10 +7,8 @@ from openmdao.jacobians.dictionary_jacobian import DictionaryJacobian
 from openmdao.core.component import Component
 from openmdao.vectors.vector import _full_slice
 from openmdao.utils.class_util import overrides_method
-from openmdao.utils.general_utils import ContainsAll
 from openmdao.recorders.recording_iteration_stack import Recording
 from openmdao.core.constants import INT_DTYPE
-from openmdao.utils.om_warnings import warn_deprecation
 
 _inst_functs = ['compute_jacvec_product']
 
