@@ -1083,11 +1083,11 @@ class TestProblem(unittest.TestCase):
         prob = om.Problem()
         G1 = prob.model.add_subsystem('G1', om.Group())
         G1.add_subsystem('C1', om.ExecComp('y=x*2.',
-                                            x={'val': 1.0, 'units': 'cm', 'src_indices': [0]},
+                                            x={'val': 1.0, 'units': 'cm', 'src_indices': [0], 'flat_src_indices': True},
                                             y={'val': 0.0, 'units': 'cm'}),
                          promotes=['x'])
         G1.add_subsystem('C2', om.ExecComp('y=x*3.',
-                                            x={'val': 1.0, 'units': 'mm', 'src_indices': [1,2]},
+                                            x={'val': np.ones(2), 'units': 'mm', 'src_indices': [1,2], 'flat_src_indices': True},
                                             y={'val': np.zeros(2), 'units': 'mm'}),
                          promotes=['x'])
         G1.add_subsystem('C3', om.ExecComp('y=x*4.',
@@ -2071,21 +2071,6 @@ class TestProblem(unittest.TestCase):
             prob.set_val('x', 0.)
         self.assertEqual(str(cm.exception), "Problem: 'x' Cannot call set_val before setup.")
 
-    def test_nonflat_flat_inds(self):
-        # this tests when we have src_indices that refer to a flat source and are defined
-        # as 'flat_src_indices' but are not themselves in a flat array (in this case they're
-        # in a column array).
-        p = om.Problem()
-        p.model.add_subsystem('ivc', om.IndepVarComp('x', val=np.ones((3,3))))
-        p.model.add_subsystem('comp', om.ExecComp('y=x*2', shape=(3, 1)))
-        p.model.connect('ivc.x', 'comp.x', src_indices=np.arange(3, dtype=int).reshape((3,1)),
-                        flat_src_indices=True)
-        p.setup()
-        p.run_model()
-
-        # this test passes if it doesn't raise an exception here...
-        p['comp.x'] = np.arange(3) + 1.
-
 
 class NestedProblemTestCase(unittest.TestCase):
 
