@@ -268,7 +268,7 @@ class TestSystem(unittest.TestCase):
             inputs = p.model.list_inputs(values=True, out_stream=None)
         self.assertEqual(inputs, [('comp.a', {'val': 1})])
 
-        msg = "The metadata key 'value' will be deprecated in 4.0. Please use 'val'"
+        msg = "The metadata key 'value' will be deprecated in 4.0. Please use 'val'."
         with assert_warning(OMDeprecationWarning, msg):
             self.assertEqual(inputs[0][1]['value'], 1)
 
@@ -283,7 +283,7 @@ class TestSystem(unittest.TestCase):
             outputs = p.model.list_outputs(values=True, out_stream=None)
         self.assertEqual(outputs, [('comp.b', {'val': 2})])
 
-        msg = "The metadata key 'value' will be deprecated in 4.0. Please use 'val'"
+        msg = "The metadata key 'value' will be deprecated in 4.0. Please use 'val'."
         with assert_warning(OMDeprecationWarning, msg):
             self.assertEqual(outputs[0][1]['value'], 2)
 
@@ -291,6 +291,14 @@ class TestSystem(unittest.TestCase):
         with assert_warning(OMDeprecationWarning, msg):
             self.assertEqual(meta['comp.a']['value'], 1)
 
+        with assert_warning(OMDeprecationWarning, msg):
+            meta = p.model.get_io_metadata(metadata_keys=('value',))
+        self.assertEqual(meta['comp.a']['val'], 1)
+
+        with assert_warning(OMDeprecationWarning, msg):
+            meta = p.model.get_io_metadata(metadata_keys=('value',))
+        with assert_warning(OMDeprecationWarning, msg):
+            self.assertEqual(meta['comp.a']['value'], 1)
 
     def test_recording_options_deprecated(self):
         prob = Problem()
@@ -353,6 +361,30 @@ class TestSystem(unittest.TestCase):
 
         self.assertEqual(str(cm.exception), "'comp' <class BadComp>: You forget to call super() in setup()")
 
+    def test_list_inputs_before_final_setup(self):
+        class SpeedComp(ExplicitComponent):
+
+            def setup(self):
+                self.add_input('distance', val=1.0, units='km')
+                self.add_input('time', val=1.0, units='h')
+                self.add_output('speed', val=1.0, units='km/h')
+
+            def compute(self, inputs, outputs):
+                outputs['speed'] = inputs['distance'] / inputs['time']
+
+        prob = Problem()
+        prob.model.add_subsystem('c1', SpeedComp(), promotes=['*'])
+        prob.model.add_subsystem('c2', ExecComp('f=speed',speed={'units': 'm/s'}), promotes=['*'])
+
+        prob.setup()
+
+        msg = ("Calling `list_inputs` before `final_setup` will only "
+              "display the default values of variables and will not show the result of "
+              "any `set_val` calls.")
+
+        with assert_warning(UserWarning, msg):
+            prob.model.list_inputs(units=True, prom_name=True)
+
 
 if __name__ == "__main__":
     unittest.main()
