@@ -24,11 +24,9 @@ _allowed_add_input_args = {
 
 _allowed_add_output_args = {
     'val', 'shape', 'units', 'res_units', 'desc' 'lower', 'upper', 'ref', 'ref0', 'res_ref', 'tags',
-    'shape_by_conn', 'copy_shape', 'distributed'
+    'shape_by_conn', 'copy_shape', 'distributed', 'resid'
 }
 
-_allowed_defaults_args = _allowed_add_input_args.union(_allowed_add_output_args)
-
 _allowed_declare_options_args = {
     'default', 'values', 'types', 'desc', 'upper', 'lower', 'check_valid', 'allow_none',
     'recordable', 'deprecation'
@@ -40,7 +38,7 @@ _allowed_declare_partials_args = {
 }
 
 _allowed_declare_coloring_args = {
-    'of', 'wrt', 'method', 'form', 'step', 'per_instance', 'num_full_jacs', 'tol', 'orders',
+    'wrt', 'method', 'form', 'step', 'per_instance', 'num_full_jacs', 'tol', 'orders',
     'perturb_size', 'min_improve_pct', 'show_summary', 'show_sparsity'
 }
 
@@ -79,7 +77,10 @@ class OMWrappedFunc(object):
         Initialize attributes.
         """
         self._f = func
-        self._defaults = {'val': 1.0, 'shape': ()}
+        self._input_defaults = {'val': 1.0, 'shape': ()}
+        self._output_defaults = {'val': 1.0, 'shape': ()}
+        self._partials_defaults = {}
+        self._coloring_defaults = {}
 
         # populate _inputs dict with input names based on function signature so we can error
         # check vs. inputs added via add_input
@@ -111,17 +112,36 @@ class OMWrappedFunc(object):
 
     def defaults(self, **kwargs):
         r"""
-        Add metadata that may apply to any inputs or outputs of the wrapped function.
+        Add default metadata that may apply to the wrapped function.
 
-        Any variable specific metadata will override metadata specified here.
+        Any variable specific or partials/coloring specific metadata will override any metadata
+        specified here.
 
         Parameters
         ----------
         **kwargs : dict
             Metadata names and their values.
         """
-        _check_kwargs(kwargs, _allowed_defaults_args, 'defaults')
-        self._defaults.update(kwargs)
+        input_kwargs = _filter_dict(kwargs, _allowed_add_input_args)
+        output_kwargs = _filter_dict(kwargs, _allowed_add_output_args)
+        partials_kwargs = _filter_dict(kwargs, _allowed_declare_partials_args)
+        coloring_kwargs = _filter_dict(kwargs, _allowed_declare_coloring_args)
+
+        combined = (set(input_kwargs)
+                    .union(output_kwargs)
+                    .union(partials_kwargs)
+                    .union(coloring_kwargs))
+
+        if len(kwargs) > len(combined):
+            invalids = (set(kwargs) - _allowed_add_input_args - _allowed_add_output_args -
+                        _allowed_declare_partials_args - _allowed_declare_coloring_args)
+            raise NameError(f"In defaults, metadata names {sorted(invalids)} are not allowed.")
+
+        self._input_defaults.update(input_kwargs)
+        self._output_defaults.update(output_kwargs)
+        self._partials_defaults.update(partials_kwargs)
+        self._coloring_defaults.update(coloring_kwargs)
+
         return self
 
     def add_input(self, name, **kwargs):
@@ -142,8 +162,6 @@ class OMWrappedFunc(object):
             if kw in meta and meta[kw] is not None:
                 raise RuntimeError(f"In add_input, metadata '{kw}' has already been added to "
                                    f"function for input '{name}'.")
-        if meta.get('val') is not None and kwargs.get('val') is not None:
-            self._check_vals_equal(name, meta['val'], kwargs['val'])
         _check_kwargs(kwargs, _allowed_add_input_args, 'add_input')
         meta.update(kwargs)
         return self
@@ -174,7 +192,10 @@ class OMWrappedFunc(object):
             Keyword args to store.
         """
         if name in self._inputs:
-            raise RuntimeError(f"In add_output, '{name}' already registered as an input.")
+            if 'resid' in kwargs:
+                self._inputs[name]['resid'] = kwargs['resid']
+            else:
+                raise RuntimeError(f"In add_output, '{name}' already registered as an input.")
         if name in self._outputs:
             raise RuntimeError(f"In add_output, '{name}' already registered as an output.")
         _check_kwargs(kwargs, _allowed_add_output_args, 'add_output')
@@ -224,23 +245,47 @@ class OMWrappedFunc(object):
             Keyword args to store.
         """
         _check_kwargs(kwargs, _allowed_declare_options_args, 'declare_option')
+        del self._inputs[name]['val']  # 'val' isn't a valid arg to declare_option
         self._inputs[name].update(kwargs)
         self._inputs[name]['is_option'] = True
         return self
 
-    def declare_partials(self, **kwargs):
+    def declare_partials(self, of=('*',), wrt=('*',), **kwargs):
         r"""
         Collect args to be passed to declare_partials on an OpenMDAO component.
 
         Parameters
         ----------
+        of : str or list of str
+            Individual name/glob pattern or list of names/glob patterns to match
+            'of' variables.
+        wrt : str or list of str
+            Individual name/glob pattern or list of names/glob patterns to match
+            'with respect to' variables.
         **kwargs : dict
             Keyword args to store.
         """
         _check_kwargs(kwargs, _allowed_declare_partials_args, 'declare_partials')
-        self._declare_partials.append(kwargs)
+        _update_from_defaults(kwargs, self._partials_defaults)
+
+        jaxerr = False
         if 'method' in kwargs and kwargs['method'] == 'jax':
+            if self._declare_partials and not self._use_jax:
+                jaxerr = True
             self._use_jax = True
+        elif self._use_jax:
+            jaxerr = True
+
+        if jaxerr:
+            raise RuntimeError("If multiple calls to declare_partials() are made on the same "
+                               "function object and any set method='jax', then all must set "
+                               "method='jax'.")
+
+        kwargs = kwargs.copy()
+        kwargs['of'] = of
+        kwargs['wrt'] = wrt
+        self._declare_partials.append(kwargs)
+
         return self
 
     def declare_coloring(self, **kwargs):
@@ -254,6 +299,7 @@ class OMWrappedFunc(object):
         """
         if self._declare_coloring is None:
             _check_kwargs(kwargs, _allowed_declare_coloring_args, 'declare_coloring')
+            _update_from_defaults(kwargs, self._coloring_defaults)
             self._declare_coloring = kwargs.copy()
             return self
         raise RuntimeError("declare_coloring has already been called.")
@@ -264,12 +310,12 @@ class OMWrappedFunc(object):
 
         Returns
         -------
-        iter of (str, dict)
-            Iterator of (name, metdata_dict) for each input variable.
+        list of (str, dict)
+            List containing (name, metdata_dict) for each input variable.
         """
         if self._call_setup:
             self._setup()
-        return self._inputs.items()
+        return [it for it in self._inputs.items() if 'resid' not in it[1]]
 
     def get_input_names(self):
         """
@@ -280,8 +326,7 @@ class OMWrappedFunc(object):
         str
             Name of each input variable.
         """
-        for name, _ in self.get_input_meta():
-            yield name
+        yield from inspect.signature(self._f).parameters
 
     def get_output_meta(self):
         """
@@ -330,130 +375,79 @@ class OMWrappedFunc(object):
         """
         return self._declare_coloring
 
-    def _check_vals_equal(self, name, val1, val2):
-        """
-        Compare two values that could be a mix of ndarray and other types.
-
-        Parameters
-        ----------
-        name : str
-            Name of the variable (for error reporting).
-        val1 : object
-            First value.
-        val2 : object
-            Second value.
-        """
-        # == is more prone to raise exceptions when ndarrays are involved, so use !=
-        neq = val1 != val2
-        if (isinstance(neq, np.ndarray) and np.any(neq)) or neq:
-            raise RuntimeError(f"Conflicting metadata entries for '{name}'.")
-
-    def _resolve_default(self, key, meta):
-        """
-        Update the value of the metadata corresponding to key based on self._defaults.
-
-        Parameters
-        ----------
-        key : str
-            The metadata entry key.
-        meta : dict
-            The metadata dict to be updated.
-        """
-        if (key not in meta or meta[key] is None) and key in self._defaults:
-            meta[key] = self._defaults[key]
-
     def _setup(self):
         """
         Set up input and output variable metadata dicts.
         """
         self._call_setup = False
-        overrides = set(self._defaults)
 
-        self._setup_inputs(overrides)
-        self._setup_outputs(overrides)
+        self._setup_inputs()
+        self._setup_outputs()
 
-    def _setup_inputs(self, overrides):
+    def _setup_inputs(self):
         """
         Set up the input variable metadata dicts.
-
-        Parameters
-        ----------
-        overrides : set
-            Set of names of entries in self._defaults.
         """
         ins = self._inputs
-        overrides = overrides - {'val', 'shape'}
+        outs = self._outputs
 
         # first, retrieve inputs from the function signature
         for name in inspect.signature(self._f).parameters:
             meta = ins[name]
+
             if meta.get('is_option'):
                 continue
 
-            if 'val' in meta and meta['val'] is not None:
-                valshape = np.asarray(meta['val']).shape
+            if name in outs:  # skip if this is a state
+                defaults = self._output_defaults
             else:
-                valshape = None
-                meta['val'] = self._defaults['val']
+                defaults = self._input_defaults
 
-            if meta.get('shape') is None:
-                if valshape is not None:
-                    meta['shape'] = valshape
-                else:
-                    meta['shape'] = self._defaults['shape']
+            self._default_to_shape(name, meta, defaults)
+            _update_from_defaults(meta, defaults)
 
-            meta['shape'] = _shape2tuple(meta['shape'])
-            if not valshape:  # val is a scalar so reshape with the given meta['shape']
-                meta['val'] = np.ones(meta['shape']) * meta['val']
-            elif valshape != meta['shape']:
-                raise ValueError(f"Input '{name}' default value has shape "
-                                 f"{valshape}, but shape was specified as {meta['shape']}.")
-
-            for o in overrides:
-                self._resolve_default(o, meta)
-
-    def _setup_outputs(self, overrides):
+    def _setup_outputs(self):
         """
         Set up the output variable metadata dicts.
-
-        Parameters
-        ----------
-        overrides : set
-            Set of names of entries in self._defaults.
         """
-        outmeta = {}
-
-        # Parse the function code to possibly identify the names of the return values and
-        # input/output dependencies. Return names will be non-None only if they are a simple name,
-        # e.g., return a, b, c
+        # Parse the function code to possibly identify the names of the return values Return names
+        # will be non-None only if they are a simple name, e.g., return a, b, c
         outlist = []
         try:
-            ret_info = get_function_deps(self._f)
-        except RuntimeError:
-            #  this could happen if function is compiled or has multiple return lines
+            outlist = [(n, {}) for n in self.get_return_names()]
+        except RuntimeError as err:
+            # this could happen if function is compiled or has multiple return lines that are
+            # not all consistent
+            msg = (f"During AST processing to determine the number and name of return values, the "
+                   f"following error occurred: {err}")
             if not self._outputs:
-                raise RuntimeError(f"Couldn't determine function return names or "
-                                   "number of return values based on AST and no return value "
-                                   "metadata was supplied.")
-            warnings.warn("Couldn't determine function return names based on AST.  Assuming number "
-                          "of return values matches number of outputs defined in the metadata.")
+                raise RuntimeError(msg)
+            warnings.warn(f"{msg}\nError was ignored and will proceed assuming that the number "
+                          f"of return values matches the number of outputs ({len(self._outputs)}) "
+                          "defined in the metadata.")
             outlist = list(self._outputs.items())
-        else:
-            for o, deps in ret_info:
-                outlist.append([o, {'deps': deps}])
 
+        residmap = {n: n for n, _ in outlist}
         notfound = []
         for oname, ometa in self._outputs.items():
+            residmap[oname] = oname
             for n, meta in outlist:
-                if n == oname:
+                if n == oname or 'resid' in ometa and ometa['resid'] == n:
                     if meta is not ometa:
                         meta.update(ometa)
+                    residmap[n] = oname
                     break
             else:  # didn't find oname
                 notfound.append(oname)
 
+        inones = [i for i, t in enumerate(outlist) if t[0] is None]  # indices with no name
+
+        if len(inones) > len(self._outputs):
+            raise RuntimeError(f"{len(self._outputs)} output names are specified in the metadata "
+                               f"but there are {len(inones)} unnamed return values in the "
+                               "function.")
+
         if notfound:  # try to fill in the unnamed slots with user-supplied output data
-            inones = [i for i, (n, m) in enumerate(outlist) if n is None]  # indices with no name
             if len(notfound) != len(inones):
                 raise RuntimeError(f"There must be an unnamed return value for every unmatched "
                                    f"output name {notfound} but only found {len(inones)}.")
@@ -465,19 +459,34 @@ class OMWrappedFunc(object):
                 ret_meta.update(m)
                 outlist[i_olist] = (name_notfound, ret_meta)
 
-        outs = {n: m for n, m in outlist}
+        outs = {residmap[n]: m for n, m in outlist}
 
         if self._use_jax:
+            # make sure jax used for all declared derivs
             self._compute_out_shapes(self._inputs, outs)
 
-        for meta in outs.values():
-            for o in overrides:
-                self._resolve_default(o, meta)
+        for name, meta in outs.items():
+            self._default_to_shape(name, meta, self._output_defaults)
+            _update_from_defaults(meta, self._output_defaults)
             if meta['shape'] is not None:
                 meta['shape'] = _shape2tuple(meta['shape'])
 
         self._outputs = outs
 
+    def get_return_names(self):
+        """
+        Return list of return value names.
+
+        Returns
+        -------
+        list
+            List of names containing one entry for each return value.  Each name will be the
+            name of the return value if it has a simple name, otherwise None.
+        """
+        input_names = set(self.get_input_names())
+        return [n if n not in input_names else None
+                for n in _FuncRetNameCollector(self._f).get_return_names()]
+
     def _compute_out_shapes(self, ins, outs):
         """
         Compute the shapes of outputs based on those of the inputs.
@@ -497,7 +506,8 @@ class OMWrappedFunc(object):
                 need_shape.append(name)
 
         args = []
-        for name, meta in ins.items():
+        static_argnums = []
+        for i, (name, meta) in enumerate(ins.items()):
             if 'is_option' in meta and meta['is_option']:
                 if 'default' in meta:
                     val = meta['default']
@@ -506,6 +516,7 @@ class OMWrappedFunc(object):
                 else:
                     val = None
                 args.append(val)
+                static_argnums.append(i)
                 continue
             if meta['val'] is not None:
                 args.append(meta['val'])
@@ -513,43 +524,77 @@ class OMWrappedFunc(object):
                 try:
                     shp = meta['shape']
                 except KeyError:
-                    raise RuntimeError(f"Can't determine shape of input '{name}'.")
-                if jax is not None:
-                    args.append(jax.ShapedArray(_shape2tuple(shp), dtype=np.float64))
-
-        # compute shapes as a check against annotated value (if any)
-        if jax is not None:
-            # must replace numpy with jax numpy when making jaxpr.
-            with jax_context(self._f.__globals__):
-                try:
-                    v = jax.make_jaxpr(self._f)(*args)
-                except Exception as err:
-                    if need_shape:
-                        raise RuntimeError(f"Failed to determine the output shapes "
-                                           f"based on the input shapes. The error was: {err}.  To "
-                                           "avoid this error, add return value annotations that "
-                                           "specify the shapes of the return values to the "
-                                           "function.")
-                    warnings.warn("Failed to determine the output shapes based on the input "
-                                  "shapes in order to check the provided annotated values. The"
-                                  f" error was: {err}.")
+                    if 'resid' not in meta:  # this is an input, not a state
+                        raise RuntimeError(f"Can't determine shape of input '{name}'.")
                 else:
-                    for val, name in zip(v.out_avals, outs):
-                        oldshape = outs[name].get('shape')
-                        if oldshape is not None and _shape2tuple(oldshape) != val.shape:
-                            raise RuntimeError(f"Annotated shape for return value "
-                                               f"'{name}' of {oldshape} doesn't match computed "
-                                               f"shape of {val.shape}.")
-                        outs[name]['shape'] = val.shape
-                    need_shape = []
+                    if jax is not None:
+                        shp = None if shp is None else _shape2tuple(shp)
+                        args.append(jax.ShapedArray(shp, dtype=np.float64))
+
+        # compute shapes as a check against shapes in metadata (if any)
+        if jax is not None:
+            try:
+                # must replace numpy with jax numpy when making jaxpr.
+                with jax_context(self._f.__globals__):
+                    v = jax.make_jaxpr(self._f, static_argnums)(*args)
+            except Exception as err:
+                if need_shape:
+                    raise RuntimeError(f"Failed to determine the output shapes "
+                                       f"based on the input shapes. The error was: {err}.  To "
+                                       "avoid this error, add return value metadata that "
+                                       "specifies the shapes of the return values to the function.")
+                warnings.warn("Failed to determine the output shapes based on the input "
+                              "shapes in order to check the provided metadata values. The"
+                              f" error was: {err}.")
+            else:
+                for val, name in zip(v.out_avals, outs):
+                    oldshape = outs[name].get('shape')
+                    if oldshape is not None and _shape2tuple(oldshape) != val.shape:
+                        raise RuntimeError(f"shape from metadata for return value "
+                                           f"'{name}' of {oldshape} doesn't match computed "
+                                           f"shape of {val.shape}.")
+                    outs[name]['shape'] = val.shape
+                need_shape = []
 
         if need_shape:  # output shapes weren't provided by user or by jax
-            shape = self._defaults['shape']
+            shape = self._output_defaults['shape']
             warnings.warn(f"Return values {need_shape} have unspecified shape so are assumed to "
                           f"have shape {shape}.")
             for name in need_shape:
                 outs[name]['shape'] = shape
 
+    def _default_to_shape(self, name, meta, defaults_dict):
+        """
+        Set shape based on default value or various metadata.
+
+        Parameters
+        ----------
+        name : str
+            Name of the variable.
+        meta : dict
+            Variable metadata dict.
+        defaults_dict : dict
+            Function defaults dict.
+        """
+        if 'val' in meta and meta['val'] is not None:
+            valshape = np.asarray(meta['val']).shape
+        else:
+            valshape = None
+            meta['val'] = defaults_dict['val']
+
+        if meta.get('shape') is None:
+            if valshape is not None:
+                meta['shape'] = valshape
+            else:
+                meta['shape'] = defaults_dict['shape']
+
+        meta['shape'] = _shape2tuple(meta['shape'])
+        if not valshape:  # val is a scalar so reshape with the given meta['shape']
+            meta['val'] = np.ones(meta['shape']) * meta['val']
+        elif valshape != meta['shape']:
+            raise ValueError(f"Input '{name}' value has shape "
+                             f"{valshape}, but shape was specified as {meta['shape']}.")
+
 
 def wrap(func):
     """
@@ -572,26 +617,39 @@ def wrap(func):
     return OMWrappedFunc(func)
 
 
-def _get_kwargs(func, locals_dict, default=None):
+def _update_from_defaults(meta, defaults):
     """
-    Convert a function's args to a kwargs dict containing entries that are not identically default.
+    Update values of the metadata corresponding to defaults.
 
     Parameters
     ----------
-    func : function
-        The function whose args we want to convert to kwargs.
-    locals_dict : dict
-        The locals dict for the function.
-    default : object
-        Don't include arguments whose values are this object.
+    meta : dict
+        The metadata dict to be updated.
+    defaults : dict
+        The defaults dict.
+    """
+    for key, val in defaults.items():
+        if key not in meta or meta[key] is None:
+            meta[key] = val
+
+
+def _filter_dict(dct, allowed):
+    """
+    Copy the dict, keeping only values corresponding to allowed.
+
+    Parameters
+    ----------
+    dct : dict
+       Dictionary to copy.
+    allowed : set or dict
+       Only values matching these keys will be copied.
 
     Returns
     -------
     dict
-        The non-default keyword args dict.
+       A copy of the dict containing only allowed values.
     """
-    return {n: locals_dict[n] for n in inspect.signature(func).parameters
-            if locals_dict[n] is not default}
+    return {k: v for k, v in dct.items() if k in allowed}
 
 
 def _check_kwargs(kwargs, allowed, fname):
@@ -628,8 +686,6 @@ def _shape2tuple(shape):
     """
     if isinstance(shape, Number):
         return (shape,)
-    elif shape is None:
-        return shape
     return tuple(shape)
 
 
@@ -659,45 +715,9 @@ def jax_context(globals):
             globals['numpy'] = savenumpy
 
 
-def _get_long_name(node):
+class _FuncRetNameCollector(ast.NodeVisitor):
     """
-    Return a name (possibly dotted) corresponding to the give node or None.
-
-    If the node is a Name node or an Attribute node that is composed only of other Attribute or
-    Name nodes, then return the full dotted name for this node. Otherwise, i.e., if this node
-    contains other expressions.
-
-    Parameters
-    ----------
-    node : ASTnode
-        A node of an abstract syntax tree.
-
-    Returns
-    -------
-    str or None
-        Name corresponding to the given node.
-    """
-    if isinstance(node, ast.Name):
-        return node.id
-    elif not isinstance(node, ast.Attribute):
-        return None
-    val = node.value
-    parts = [node.attr]
-    while True:
-        if isinstance(val, ast.Attribute):
-            parts.append(val.attr)
-            val = val.value
-        elif isinstance(val, ast.Name):
-            parts.append(val.id)
-            break
-        else:  # it's more than just a simple dotted name
-            return None
-    return '.'.join(parts[::-1])
-
-
-class _FuncDepCollector(ast.NodeVisitor):
-    """
-    An ast.NodeVisitor that records dependencies between inputs and outputs.
+    An ast.NodeVisitor that records return value names.
 
     Each instance of this is single-use.  If needed multiple times create a new instance
     each time.  It also assumes that the AST to be visited contains only a single function
@@ -705,65 +725,56 @@ class _FuncDepCollector(ast.NodeVisitor):
 
     Attributes
     ----------
-    _ret_info : list
-        List containing name (or None) for each function return value.
+    _ret_infos : list
+        List containing one entry for each return statement, with each entry containing a list of
+        name (or None) for each function return value.
     """
 
     def __init__(self, func):
         super().__init__()
-        self._attrs = None
-        self._deps = {}
-        self._ret_info = []
+        self._ret_infos = []
         self.visit(ast.parse(textwrap.dedent(inspect.getsource(func)), mode='exec'))
 
-    def _do_assign(self, targets, rhs):
-        lhs_attrs = []
-        for t in targets:
-            lhs_attrs.append(_get_long_name(t))
+    def get_return_names(self):
+        """
+        Return a list of (name or None) for each return value.
 
-        self._attrs = set()
-        self.visit(rhs)
+        If there are multiple returns that differ by name or number of return values, an exception
+        will be raised.  If one entry in one return list has a name and another is None, the name
+        will take precedence and no exception will be raised.
 
-        for a in lhs_attrs:
-            if a not in self._deps:
-                self._deps[a] = set()
-            self._deps[a].update(self._attrs)
+        Returns
+        -------
+        list
+            The list of return names.  Some entries will be None if there was no simple name
+            associated with a given return value.
+        """
+        if len(self._ret_infos) == 0:
+            return []
+        if len(self._ret_infos) == 1:
+            return self._ret_infos[0]
 
-        self._attrs = None
+        names = self._ret_infos[0].copy()
+        length = len(names)
+        for lst in self._ret_infos:
+            if len(lst) != length:
+                raise RuntimeError("Function has multiple return statements with differing numbers "
+                                   "of return values.")
 
-    def visit_Attribute(self, node):
-        if self._attrs is not None:
-            self._attrs.add(_get_long_name(node))
-
-    def visit_Name(self, node):
-        if self._attrs is not None:
-            self._attrs.add(node.id)
-
-    def visit_Assign(self, node):
-        self._do_assign(node.targets, node.value)
-
-    def visit_AugAssign(self, node):
-        self._do_assign((node.target,), node.value)
-
-    def visit_AnnAssign(self, node):
-        if node.value is not None:
-            self._do_assign((node.target,), node.value)
-
-    def visit_Call(self, node):  # (func, args, keywords, starargs, kwargs)
-        for arg in node.args:
-            self.visit(arg)
-
-        for kw in node.keywords:
-            self.visit(kw.value)
+            for i, (name, newname) in enumerate(zip(names, lst)):
+                if name is None:
+                    names[i] = newname
+                elif newname is not None and name != newname:
+                    raise RuntimeError("Function has multiple return statements with different "
+                                       f"return value names of {sorted((name, newname))} for "
+                                       f"return value {i}.")
+        return names
 
     def _get_return_attrs(self, node):
-        self._attrs = set()
-
-        self.visit(node)
-        # also include a boolean indicating if the return expr is a simple name
-        self._ret_info.append((tuple(self._attrs), isinstance(node, ast.Name)))
-
-        self._attrs = None
+        if isinstance(node, ast.Name):
+            self._ret_infos[-1].append(node.id)
+        else:
+            self._ret_infos[-1].append(None)
 
     def visit_Return(self, node):
         """
@@ -774,53 +785,10 @@ class _FuncDepCollector(ast.NodeVisitor):
         node : ASTnode
             The return node being visited.
         """
-        if self._ret_info:
-            raise RuntimeError("_FuncDepCollector does not support multiple returns in a "
-                               "single function.  Either the given function contains multiple "
-                               "returns or this _FuncDepCollector instance has been used "
-                               "more than once, which is unsupported.")
+        self._ret_infos.append([])
 
         if isinstance(node.value, ast.Tuple):
             for n in node.value.elts:
                 self._get_return_attrs(n)
         else:
             self._get_return_attrs(node.value)
-
-
-def get_function_deps(func):
-    """
-    Return dependency between return value(s) and inputs.
-
-    Parameters
-    ----------
-    func : function
-        The function used to compute input/output dependencies.
-
-    Returns
-    -------
-    list
-        List of the form (name or None, dependency_set) containing one entry for each return
-        value.  'name' will be the name of the return value if it has a simple name, otherwise
-        None.
-    """
-    input_names = set(inspect.signature(func).parameters)
-    funcdeps = _FuncDepCollector(func)
-    deps = funcdeps._deps
-    retdeps = []
-    for names, _ in funcdeps._ret_info:
-        depset = set()
-        for n in names:
-            stack = [n]
-            seen = set()
-            while stack:
-                v = stack.pop()
-                seen.add(v)
-                if v in input_names:
-                    depset.add(v)
-                elif v in deps:
-                    stack.extend([d for d in deps[v] if d not in seen])
-
-        retdeps.append(depset)
-
-    return [(n[0] if simple and n[0] not in input_names else None, d)
-            for ((n, simple), d) in zip(funcdeps._ret_info, retdeps)]
