@@ -9,27 +9,34 @@ class DictionaryJacobian(Jacobian):
     """
     No global <Jacobian>; use dictionary of user-supplied sub-Jacobians.
 
+    Parameters
+    ----------
+    system : System
+        Parent system to this jacobian.
+    **kwargs : dict
+        Options dictionary.
+
     Attributes
     ----------
     _iter_keys : list of (vname, vname) tuples
         List of tuples of variable names that match subjacs in the this Jacobian.
+    _is_explicit : bool
+        True if corresponding system is an ExplicitComponent
     """
 
     def __init__(self, system, **kwargs):
         """
         Initialize all attributes.
-
-        Parameters
-        ----------
-        system : System
-            Parent system to this jacobian.
-        **kwargs : dict
-            options dictionary.
         """
         super().__init__(system, **kwargs)
-        self._iter_keys = {}
+        self._iter_keys = None
 
-    def _iter_abs_keys(self, system, vec_name):
+        # avoid circular import
+        from openmdao.core.explicitcomponent import ExplicitComponent
+
+        self._is_explicit = isinstance(system, ExplicitComponent)
+
+    def _iter_abs_keys(self, system):
         """
         Iterate over subjacs keyed by absolute names.
 
@@ -39,17 +46,13 @@ class DictionaryJacobian(Jacobian):
         ----------
         system : System
             System that is updating this jacobian.
-        vec_name : str
-            The name of the current RHS vector.
 
         Returns
         -------
         list
             List of keys matching this jacobian for the current system.
         """
-        entry = (system.pathname, vec_name)
-
-        if entry not in self._iter_keys:
+        if self._iter_keys is None:
             subjacs = self._subjacs_info
             keys = []
             for res_name in system._var_abs2meta['output']:
@@ -59,9 +62,9 @@ class DictionaryJacobian(Jacobian):
                         if key in subjacs:
                             keys.append(key)
 
-            self._iter_keys[entry] = keys
+            self._iter_keys = keys
 
-        return self._iter_keys[entry]
+        return self._iter_keys
 
     def _apply(self, system, d_inputs, d_outputs, d_residuals, mode):
         """
@@ -80,9 +83,6 @@ class DictionaryJacobian(Jacobian):
         mode : str
             'fwd' or 'rev'.
         """
-        # avoid circular import
-        from openmdao.core.explicitcomponent import ExplicitComponent
-
         fwd = mode == 'fwd'
         d_res_names = d_residuals._names
         d_out_names = d_outputs._names
@@ -95,15 +95,14 @@ class DictionaryJacobian(Jacobian):
         oflat = d_outputs._abs_get_val
         iflat = d_inputs._abs_get_val
         subjacs_info = self._subjacs_info
-        is_explicit = isinstance(system, ExplicitComponent)
 
         with system._unscaled_context(outputs=[d_outputs], residuals=[d_residuals]):
-            for abs_key in self._iter_abs_keys(system, d_residuals._name):
+            for abs_key in self._iter_abs_keys(system):
                 res_name, other_name = abs_key
                 if res_name in d_res_names:
                     if other_name in d_out_names:
                         # skip the matvec mult completely for identity subjacs
-                        if is_explicit and res_name is other_name:
+                        if self._is_explicit and res_name is other_name:
                             if fwd:
                                 val = rflat(res_name)
                                 val -= oflat(other_name)
@@ -183,6 +182,8 @@ class _CheckingJacobian(DictionaryJacobian):
             rows = meta['rows']
             if rows is None:
                 yield key, meta['val']
+            elif 'directional' in meta:
+                yield key, np.atleast_2d(meta['val']).T
             else:
                 dense = np.zeros(meta['shape'])
                 dense[rows, meta['cols']] = meta['val']
@@ -200,21 +201,29 @@ class _CheckingJacobian(DictionaryJacobian):
         for of, start, end, _, _ in system._jac_of_iter():
             nrows = end - start
             for wrt, wstart, wend, _, _, _ in system._jac_wrt_iter():
-                ncols = wend - wstart
-                loc_wrt = wrt.rsplit('.', 1)[-1]
-                directional = (local_opts is not None and loc_wrt in local_opts and
-                               local_opts[loc_wrt]['directional'])
+                if local_opts:
+                    loc_wrt = wrt.rsplit('.', 1)[-1]
+                    directional = (loc_wrt in local_opts and
+                                   local_opts[loc_wrt]['directional'])
+                else:
+                    directional = False
                 key = (of, wrt)
                 if key not in self._subjacs_info:
+                    ncols = wend - wstart
                     # create subjacs_info objects for matrix_free systems that don't have them
                     self._subjacs_info[key] = {
                         'rows': None,
                         'cols': None,
                         'val': np.zeros((nrows, 1 if directional else ncols)),
                     }
-                elif directional and self._subjacs_info[key]['val'].shape[1] != 1:
-                    self._subjacs_info[key] = meta = self._subjacs_info[key].copy()
-                    meta['val'] = np.atleast_2d(meta['val'][:, 0]).T
+                elif directional:
+                    shape = self._subjacs_info[key]['val'].shape
+                    if shape[-1] != 1:
+                        self._subjacs_info[key] = meta = self._subjacs_info[key].copy()
+                        if len(shape) > 1:
+                            meta['val'] = np.atleast_2d(meta['val'][:, 0]).T
+                        else:
+                            meta['val'] = np.atleast_1d(meta['val'])
 
     def set_col(self, system, icol, column):
         """
@@ -233,17 +242,22 @@ class _CheckingJacobian(DictionaryJacobian):
             Column index.
         column : ndarray
             Column value.
-
         """
-        if self._colnames is None:
+        if self._col_varnames is None:
             self._setup_index_maps(system)
 
-        wrt = self._colnames[self._col2name_ind[icol]]
-        _, offset, _, _, _, _ = self._col_var_info[wrt]
-        loc_idx = icol - offset  # local col index into subjacs
+        wrt = self._col_varnames[self._col2name_ind[icol]]
+        loc_idx = icol - self._col_var_offset[wrt]  # local col index into subjacs
 
         scratch = np.zeros(column.shape)
 
+        # If we are doing a directional derivative, then the sparsity will be violated.
+        # Skip sparsity check if that is the case.
+        options = system._get_check_partial_options()
+        loc_wrt = wrt.split('.')[-1]
+        directional = (options is not None and loc_wrt in options and
+                       options[loc_wrt]['directional'])
+
         for of, start, end, _, _ in system._jac_of_iter():
             key = (of, wrt)
             if key in self._subjacs_info:
@@ -257,6 +271,11 @@ class _CheckingJacobian(DictionaryJacobian):
                         subjac['val'][match_inds] = column[start:end][row_inds]
                     else:
                         row_inds = np.zeros(0, dtype=INT_DTYPE)
+
+                    if directional:
+                        subjac['directional'] = True
+                        continue
+
                     arr = scratch[start:end]
                     arr[:] = column[start:end]
                     arr[row_inds] = 0.
