@@ -12,6 +12,13 @@ from openmdao.matrices.coo_matrix import COOMatrix
 class DenseMatrix(COOMatrix):
     """
     Dense global matrix.
+
+    Parameters
+    ----------
+    comm : MPI.Comm or <FakeComm>
+        Communicator of the top-level system that owns the <Jacobian>.
+    is_internal : bool
+        If True, this is the int_mtx of an AssembledJacobian.
     """
 
     def _build(self, num_rows, num_cols, system=None):
