@@ -147,9 +147,8 @@ def ensure_compatible(name, value, shape=None, indices=None):
         The value of a variable.
     shape : int or tuple or list or None
         The expected or desired shape of the value.
-    indices : int or list of ints or tuple of ints or int ndarray or None
-        The indices of a source variable, used to determine shape if shape is None.
-        If shape is not None, the shape of the indices must match shape.
+    indices : Indexer or None
+        The indices into a source variable.
 
     Returns
     -------
@@ -175,16 +174,21 @@ def ensure_compatible(name, value, shape=None, indices=None):
             shape = tuple(shape)
     elif not np.isscalar(value):
         shape = np.atleast_1d(value).shape
-    if indices is not None and indices.shaped_instance() is not None:
-        if indices.src_ndim > 1 and shape is None:
+
+    if indices is not None:
+        if not indices._flat_src and shape is None:
             raise RuntimeError("src_indices for '%s' is not flat, so its input "
                                "shape must be provided." % name)
-        indshape = shape2tuple(indices.shape)
-        if shape is not None and indshape != shape:
-            raise ValueError("Shape of indices %s does not match shape of %s for '%s'." %
-                             (indshape, shape, name))
-        if shape is None:
-            shape = indshape
+        try:
+            indshape = indices.indexed_src_shape
+        except (RuntimeError, ValueError, TypeError):
+            pass  # use shape provided or shape of value and check vs. shape of indices later
+        else:
+            if shape is not None and np.product(indshape) != np.product(shape):
+                raise ValueError("Shape of indices %s does not match shape of %s for '%s'." %
+                                 (indshape, shape, name))
+            if shape is None:
+                shape = indshape
 
     if shape is None:
         # shape is not determined, assume the shape of value was intended
@@ -198,8 +202,7 @@ def ensure_compatible(name, value, shape=None, indices=None):
         else:
             value = np.atleast_1d(value).astype(np.float64)
             if value.shape != shape:
-                raise ValueError("Incompatible shape for '%s': "
-                                 "Expected %s but got %s." %
+                raise ValueError("Incompatible shape for '%s': Expected %s but got %s." %
                                  (name, shape, value.shape))
 
     return value, shape
@@ -437,7 +440,7 @@ def find_matches(pattern, var_list):
     Parameters
     ----------
     pattern : str
-        String pattern.
+        Glob pattern or variable name.
     var_list : list of str
         List of variable names to search for pattern.
 
@@ -887,6 +890,9 @@ def match_prom_or_abs(name, prom_name, includes=None, excludes=None):
     return False
 
 
+_falsey = {'0', 'false', 'no', ''}
+
+
 def env_truthy(env_var):
     """
     Return True if the given environment variable is 'truthy'.
@@ -901,7 +907,7 @@ def env_truthy(env_var):
     bool
         True if the specified environment variable is 'truthy'.
     """
-    return os.environ.get(env_var, '0').lower() not in ('0', 'false', 'no', '')
+    return os.environ.get(env_var, '0').lower() not in _falsey
 
 
 def common_subpath(pathnames):
@@ -943,7 +949,7 @@ def common_subpath(pathnames):
 
 def _is_slicer_op(indices):
     """
-    Check if an array of indices contains a colon or ellipsis operator.
+    Check if an indexer contains a slice or ellipsis operator.
 
     Parameters
     ----------
@@ -1078,82 +1084,11 @@ def convert_src_inds(parent_src_inds, parent_src_shape, my_src_inds, my_src_shap
         return my_src_inds
     elif my_src_inds is None:
         return parent_src_inds
-    ndims = my_src_inds.src_ndim
 
-    if ndims == 1:
-        return parent_src_inds.shaped_array()[my_src_inds()]
+    if my_src_inds._flat_src:
+        return parent_src_inds.shaped_array(flat=True)[my_src_inds.flat()]
     else:
-        return parent_src_inds.shaped_array().reshape(my_src_shape)[my_src_inds()]
-
-
-def shape_from_idx(src_shape, src_inds, flat_src_inds):
-    """
-    Get the shape of the result if the given src_inds were applied to an array of the given shape.
-
-    Parameters
-    ----------
-    src_shape : tuple
-        Expected shape of source variable.
-    src_inds : ndarray or fancy index
-        Indices into the source variable.
-    flat_src_inds : bool
-        If True, src_inds index into a flat array.
-
-    Returns
-    -------
-    tuple
-        Shape of the input.
-    """
-    if _is_slicer_op(src_inds):
-        if isinstance(src_inds, slice):
-            src_inds = [src_inds]
-
-        for entry in src_inds:
-            if entry is Ellipsis:
-                shp = np.empty(src_shape, dtype=bool)[src_inds].shape
-                if flat_src_inds:
-                    return (np.product(shp),)
-                return shp
-
-        if len(src_inds) != len(src_shape):
-            raise ValueError(f"src_indices {src_inds} have the wrong number of dimensions, "
-                             f"{len(src_inds)}, to index into an array of shape {src_shape}")
-
-        ret = []
-        full_slice = slice(None)
-        for i, dimsize in enumerate(src_shape):
-            slc = src_inds[i]
-            if isinstance(slc, slice):
-                if slc == full_slice:
-                    ret.append(dimsize)
-                elif (slc.start is None or slc.start < 0 or slc.stop is None or
-                      slc.stop < 0 or (slc.step is not None and slc.step < 0)):
-                    ret.append(np.empty(dimsize, dtype=bool)[slc].size)
-                else:
-                    step = slc.step
-                    if step in (None, 1):
-                        ret.append(slc.stop - slc.start)
-                    else:
-                        ret.append(1 + (slc.stop - slc.start - 1) // slc.step)
-            elif isinstance(slc, Number):
-                ret.append(1)
-            else:  # list/tuple/array
-                ret.append(len(slc))
-        return tuple(ret)
-    else:
-        if src_inds.ndim == 1:
-            flat_src_inds = True
-        if flat_src_inds:
-            return src_inds.shape
-        elif src_inds.size > 0:
-            dims = src_inds.shape[-1]
-        else:
-            return (0,)
-
-        if len(src_shape) != dims:
-            raise ValueError(f"non-flat src_indices {src_inds} have the wrong number of dimensions,"
-                             f" {dims}, to index into an array of shape {src_shape}")
-        return tuple(src_inds.shape[:-1])
+        return parent_src_inds.shaped_array(flat=False).reshape(my_src_shape)[my_src_inds()]
 
 
 def shape2tuple(shape):
